From: Konrad Rzeszutek Wilk <konrad.w...@oracle.com>

It has changed but the comments still refer to the old names.

Reviewed-by: Stefano Stabellini <stefano.stabell...@eu.citrix.com>
Signed-off-by: Konrad Rzeszutek Wilk <konrad.w...@oracle.com>
Signed-off-by: Stefano Stabellini <stefano.stabell...@eu.citrix.com>
---
 hw/xen/xen_pt.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/hw/xen/xen_pt.c b/hw/xen/xen_pt.c
index d67bccf..ba043e6 100644
--- a/hw/xen/xen_pt.c
+++ b/hw/xen/xen_pt.c
@@ -379,7 +379,7 @@ static void xen_pt_pci_write_config(PCIDevice *d, uint32_t 
addr,
         }
     }
 
     /* need to shift back before passing them to xen_host_pci_device */
     val >>= (addr & 3) << 3;
 
     memory_region_transaction_commit();
@@ -407,7 +407,7 @@ out:
                                     (uint8_t *)&val + index, len);
 
         if (rc < 0) {
-            XEN_PT_ERR(d, "pci_write_block failed. return value: %d.\n", rc);
+            XEN_PT_ERR(d, "xen_host_pci_set_block failed. return value: 
%d.\n", rc);
         }
     }
@@ -379,7 +379,7 @@ static void xen_pt_pci_write_config(PCIDevice *d, uint32_t 
     }
 
-    /* need to shift back before passing them to xen_host_pci_device */
+    /* need to shift back before passing them to xen_host_pci_set_block. */
     val >>= (addr & 3) << 3;
 
 }
-- 
1.7.10.4


Reply via email to